import React from 'react';
import { P, Code, A, H2, Hr, H3, Div } from '@cloudflare/elements';

export default ({
  ExamplePreview,
  BestPractice,
  PropTable,
  PropRow,
  snippetScope
}) => {
  return (
    <>
      <P mt={0} mb={3}>
        An input is used to accept data from the customer. It supports various
        textual formats, including numbers, passwords, and email addresses.
      </P>

      <BestPractice
        type="info"
        title="Only ask for necessary information"
        description={
          <span>
            Filling out forms correctly takes time and effort for a customer,
            and often distracts from achieving their intended task. Respect the
            customers time by only aking for the information required to solve
            their problem.
          </span>
        }
      />

      <P>
        Our input component generally matches the DOM API for input elements.
        The default <Code>type</Code> for an input is <Code>text</Code>.
      </P>
      <ExamplePreview
        scope={{ ...snippetScope }}
        code={`<Form>
    <Label htmlFor="input" display="block" mb={2}>Input Label</Label>
    <Input id="input" value="My Input" />
  </Form>`}
      />

      <P>
        Make sure to provide a label describing the content and purpose of the
        input. You can provide a label using either the <Code>htmlFor</Code>{' '}
        prop matching the input's <Code>id</Code> prop, or by wrapping the
        input.
      </P>

      <BestPractice
        type="encourage"
        title={
          <span>
            Ensure <Code>{'<label/>'}</Code> elements are tied to fields
          </span>
        }
        description={
          <span>
            Use either the <Code>htmlFor</Code> attribute on a label alongside
            the <Code>id</Code> attribute on your input, or wrap the input
            inside a <Code>{'<label/>'}</Code> element to ensure that the label
            and field are interactable.
          </span>
        }
      />

      <BestPractice
        type="warn"
        title={
          <span>
            Avoid using the <Code>placeholder</Code> attribute
          </span>
        }
        description={
          <span>
            The <Code>placeholder</Code> prop is considered harmful, for
            multiple accessibility reasons (primarily that content disappears,
            making it hard for customers to recall what information belongs in a
            field). See{' '}
            <A
              color="inherit"
              href="https://www.nngroup.com/articles/form-design-placeholders/"
            >
              research conducted
            </A>{' '}
            by the Nielsen Norman Group for more information.
          </span>
        }
      />

      <ExamplePreview
        scope={{ ...snippetScope }}
        code={`<Form>
    <Label>
      <P my={2}>Input Label</P>
      <Input value="My Input" />
    </Label>
  </Form>`}
      />

      <P>
        You can use the <Code>type</Code> prop to change the data types that an
        input can consume. Input currently supports the <Code>text</Code>,{' '}
        <Code>email</Code>, <Code>password</Code>, and
        <Code>number</Code> types.
      </P>
      <ExamplePreview
        scope={{ ...snippetScope }}
        code={`
    <Label>
      <P my={2}>Password</P>
      <Input value="secret-password" type="password" />
    </Label>
  `}
      />

      <ExamplePreview
        scope={{ ...snippetScope }}
        code={`
    <Label>
      <P my={2}>Email</P>
      <Input value="harley@cloudflare.com" type="email" />
    </Label>
  `}
      />

      <ExamplePreview
        scope={{ ...snippetScope }}
        code={`
    <Label>
      <P my={2}>Quantity</P>
      <Input value="100" type="number" />
    </Label>
  `}
      />

      <Hr
        my={5}
        borderTop="0px"
        borderRight="0px"
        borderLeft="0px"
        borderBottom="1px solid"
        borderColor="gray.8"
      />

      <H2>Input props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component supports all the{' '}
          <A color="inherit" href="https://styled-system.com/table">
            Styled System
          </A>{' '}
          props.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          These props are custom to this component and are based on the{' '}
          <A
            color="inherit"
            href="https://reactjs.org/docs/components-and-props.html"
          >
            React props
          </A>{' '}
          concept.
        </P>

        <PropTable cols={['Name', 'Type', 'Default', 'Description']}>
          <PropRow
            name="defaultValue"
            type="string"
            defaultVal=""
            description="A default string value that will appear on initial render"
          />
          <PropRow
            name="inputRef"
            type="func"
            defaultVal=""
            description={
              <>
                Used by{' '}
                <A color="inherit" href="https://billforward.io/">
                  billforward
                </A>{' '}
                to capture data for processing payments
              </>
            }
          />
          <PropRow
            type="string"
            defaultVal=""
            description={
              <>
                A{' '}
                <a
                  style={{ color: 'inherit' }}
                  href="https://reactjs.org/docs/refs-and-the-dom.html"
                >
                  ref
                </a>{' '}
                to access the underlying DOM element of this input
              </>
            }
          />
          <PropRow
            name="loading"
            type="boolean"
            defaultVal=""
            description={
              'Allows for conditional rendering depending on whether this is true or false, good for async data'
            }
          />
          <PropRow
            name="testId"
            type="string"
            defaultVal=""
            description={
              "Allows to attach unique Test ID's to access in integration tests"
            }
          />
        </PropTable>
      </Div>

      <Div mt={5}>
        <H3 mb={1}>Default</H3>
        <P fontSize={2} mb={3} mt={0}>
          The default properties that are provided by the{' '}
          <A
            color="inherit"
            href="https://developer.mozilla.org/en-US/docs/Web/HTML/Reference"
          >
            HTML spec
          </A>{' '}
          that can be applied to this component.
        </P>
      </Div>

      <Div mt={5} mb={5}>
        <H3 mb={1}>Events</H3>
        <P fontSize={2} mb={3} mt={0}>
          As well as the default{' '}
          <A color="inherit" href="https://reactjs.org/docs/events.html">
            React events
          </A>{' '}
          the following custom events are also available.
        </P>
      </Div>
    </>
  );
};
